# AstroPixel

[![A rectangular badge, half black half purple containing the text made at Code Astro](https://img.shields.io/badge/Made%20at-Code/Astro-blueviolet.svg)](https://semaphorep.github.io/codeastro/)
[![Documentation Status](https://readthedocs.org/projects/astropixel/badge/?version=latest)](https://astropixel.readthedocs.io/en/latest/?badge=latest)

Repository for making pixel art out of real astronomical data. 

[Try out AstroPixel in colab!](https://colab.research.google.com/github/SpacialTree/astropixel/blob/main/notebooks/astropixel_example.ipynb)

## Installation

Install via

```
pip install astropixel
```

## Credits

This package developed by:

- Savannah Gramze (`@SpacialTree <https://github.com/SpacialTree>`__)
- S M Rafee Adnan (`@rafee-adnan <https://github.com/rafee-adnan>`__)

![Pixelart of the star field around Barnard's Star](notebooks/barnardstar.png "AstroPixel Barnard's Star")
